@@ -1,5 +1,5 @@
 /* -*- mode: C; -*- */
-/* Copyright (C) 2003, 2010 TSUTSUMI Kikuo.
+/* Copyright (C) 2003, 2010, 2013 TSUTSUMI Kikuo.
    This file is part of the CCUnit Library.
 
    The CCUnit Library is free software; you can redistribute it and/or
@@ -19,7 +19,7 @@
 */
 
 /*
- * $Id: CCUnitAssert.h,v 1.15 2010/08/22 01:46:25 tsutsumi Exp $
+ * $Id$
  */
 /**@file
  * Assert functions and macros.
@@ -532,6 +532,140 @@ extern void ccunit_assert (const char* file, unsigned int line,
 #define CCUNIT_ASSERT_GE_UINT(EXPECT, ACTUAL)	\
   CCUNIT_ASSERT_TEST_UINT (EXPECT, >=, ACTUAL)
 
+/**
+ * Asserts that a condition is true. If it isn't it longjmp with
+ * _ccunit_runTest_env.
+ *
+ * @param ACTUAL actual value.
+ * @param EXPECT expect value.
+ * @throws _ccunit_runTest_env If condition is false.
+ * @ingroup Assertions
+ */
+#define CCUNIT_ASSERT_EQ_DOUBLE(EXPECT, ACTUAL)	\
+  CCUNIT_ASSERT_TEST_DOUBLE (EXPECT, ==, ACTUAL)
+/**
+ * Asserts that a condition is true. If it isn't it longjmp with
+ * _ccunit_runTest_env.
+ *
+ * @param ACTUAL actual value.
+ * @param EXPECT expect value.
+ * @throws _ccunit_runTest_env If condition is false.
+ * @ingroup Assertions
+ */
+#define CCUNIT_ASSERT_NE_DOUBLE(EXPECT, ACTUAL)	\
+  CCUNIT_ASSERT_TEST_DOUBLE (EXPECT, !=, ACTUAL)
+/**
+ * Asserts that a condition is true. If it isn't it longjmp with
+ * _ccunit_runTest_env.
+ *
+ * @param ACTUAL actual value.
+ * @param EXPECT expect value.
+ * @throws _ccunit_runTest_env If condition is false.
+ * @ingroup Assertions
+ */
+#define CCUNIT_ASSERT_LT_DOUBLE(EXPECT, ACTUAL)	\
+  CCUNIT_ASSERT_TEST_DOUBLE (EXPECT, <, ACTUAL)
+/**
+ * Asserts that a condition is true. If it isn't it longjmp with
+ * _ccunit_runTest_env.
+ *
+ * @param ACTUAL actual value.
+ * @param EXPECT expect value.
+ * @throws _ccunit_runTest_env If condition is false.
+ * @ingroup Assertions
+ */
+#define CCUNIT_ASSERT_LE_DOUBLE(EXPECT, ACTUAL)	\
+  CCUNIT_ASSERT_TEST_DOUBLE (EXPECT, <=, ACTUAL)
+/**
+ * Asserts that a condition is true. If it isn't it longjmp with
+ * _ccunit_runTest_env.
+ *
+ * @param ACTUAL actual value.
+ * @param EXPECT expect value.
+ * @throws _ccunit_runTest_env If condition is false.
+ * @ingroup Assertions
+ */
+#define CCUNIT_ASSERT_GT_DOUBLE(EXPECT, ACTUAL)	\
+  CCUNIT_ASSERT_TEST_DOUBLE (EXPECT, >, ACTUAL)
+/**
+ * Asserts that a condition is true. If it isn't it longjmp with
+ * _ccunit_runTest_env.
+ *
+ * @param ACTUAL actual value.
+ * @param EXPECT expect value.
+ * @throws _ccunit_runTest_env If condition is false.
+ * @ingroup Assertions
+ */
+#define CCUNIT_ASSERT_GE_DOUBLE(EXPECT, ACTUAL)	\
+  CCUNIT_ASSERT_TEST_DOUBLE (EXPECT, >=, ACTUAL)
+
+/**
+ * Asserts that a condition is true. If it isn't it longjmp with
+ * _ccunit_runTest_env.
+ *
+ * @param ACTUAL actual value.
+ * @param EXPECT expect value.
+ * @throws _ccunit_runTest_env If condition is false.
+ * @ingroup Assertions
+ */
+#define CCUNIT_ASSERT_EQ_FLOAT(EXPECT, ACTUAL)	\
+  CCUNIT_ASSERT_TEST_FLOAT (EXPECT, ==, ACTUAL)
+/**
+ * Asserts that a condition is true. If it isn't it longjmp with
+ * _ccunit_runTest_env.
+ *
+ * @param ACTUAL actual value.
+ * @param EXPECT expect value.
+ * @throws _ccunit_runTest_env If condition is false.
+ * @ingroup Assertions
+ */
+#define CCUNIT_ASSERT_NE_FLOAT(EXPECT, ACTUAL)	\
+  CCUNIT_ASSERT_TEST_FLOAT (EXPECT, !=, ACTUAL)
+/**
+ * Asserts that a condition is true. If it isn't it longjmp with
+ * _ccunit_runTest_env.
+ *
+ * @param ACTUAL actual value.
+ * @param EXPECT expect value.
+ * @throws _ccunit_runTest_env If condition is false.
+ * @ingroup Assertions
+ */
+#define CCUNIT_ASSERT_LT_FLOAT(EXPECT, ACTUAL)	\
+  CCUNIT_ASSERT_TEST_FLOAT (EXPECT, <, ACTUAL)
+/**
+ * Asserts that a condition is true. If it isn't it longjmp with
+ * _ccunit_runTest_env.
+ *
+ * @param ACTUAL actual value.
+ * @param EXPECT expect value.
+ * @throws _ccunit_runTest_env If condition is false.
+ * @ingroup Assertions
+ */
+#define CCUNIT_ASSERT_LE_FLOAT(EXPECT, ACTUAL)	\
+  CCUNIT_ASSERT_TEST_FLOAT (EXPECT, <=, ACTUAL)
+/**
+ * Asserts that a condition is true. If it isn't it longjmp with
+ * _ccunit_runTest_env.
+ *
+ * @param ACTUAL actual value.
+ * @param EXPECT expect value.
+ * @throws _ccunit_runTest_env If condition is false.
+ * @ingroup Assertions
+ */
+#define CCUNIT_ASSERT_GT_FLOAT(EXPECT, ACTUAL)	\
+  CCUNIT_ASSERT_TEST_FLOAT (EXPECT, >, ACTUAL)
+/**
+ * Asserts that a condition is true. If it isn't it longjmp with
+ * _ccunit_runTest_env.
+ *
+ * @param ACTUAL actual value.
+ * @param EXPECT expect value.
+ * @throws _ccunit_runTest_env If condition is false.
+ * @ingroup Assertions
+ */
+#define CCUNIT_ASSERT_GE_FLOAT(EXPECT, ACTUAL)	\
+  CCUNIT_ASSERT_TEST_FLOAT (EXPECT, >=, ACTUAL)
+
 #if CCUNIT_HAVE_QUAD_T
 /**
  * Asserts that a condition is true. If it isn't it longjmp with
